package com.nodsw.bddcourse.classcost;

import java.util.List;
import java.util.Map;

import junit.framework.Assert;

import org.jbehave.core.annotations.Given;
import org.jbehave.core.annotations.Then;
import org.jbehave.core.annotations.When;
import org.jbehave.core.model.ExamplesTable;

/**
 * Story Steps to Java Methods for presenter_is_given_class_cost.story
 */
public class ClassCostSteps {
	Meeting myMeeting;

	@Given("an empty meeting")
	public void createNewEmptyMeeting () {
		myMeeting = new Meeting();
	}
	
	@Given("no meeting count")
	public void zeroMeetingCount () {
		myMeeting.setClassSizeTo(0);
	}

	@When("attendance count is set to $classSize")
	public void setClassSizeTo ( int classSize ) {
		myMeeting.setClassSizeTo(classSize);
	}
	
	@When("average hourly rate is set to $hourlyRate")
	public void setAveraageHourlyRateTo ( double hourlyRate ) {
		myMeeting.setAveraageHourlyRateTo(hourlyRate);
	}
	
	@When("meeting length is set to $meetingLength")
	public void setMeetingLengthTo ( double meetingLength ) {
		myMeeting.setMeetingLengthTo(meetingLength);
	}

	@When("presenter adds attendee with hourly rate of: $hourlyRates")
	public void addAttendeeByRateToMeeting ( ExamplesTable hourlyRates ) {
	    List <Map<String,String>> rows = hourlyRates.getRows();
	    for (Map <String,String>row : rows) {
	        String rate = row.get("hourlyRate");
			myMeeting.addAttendeeByRateToMeeting(Double.parseDouble(rate));
	    }
	}
	
	@Then("ensure meeting cost should be $classCost")
	public void theMeetingCostShouldBe ( double classCost ) {
		Assert.assertEquals("the meeting cost is incorrect", classCost, myMeeting.getMeetingCost());
	}
	
	@Then("meeting count should be $classSize")
	public void theMeetingSizeShouldBe ( int classSize ) {
		Assert.assertEquals("the meeting size is incorrect", classSize, myMeeting.getMeetingSize());
	}
	
	@Then("ensure meeting cost should not be available")
	public void theMeetingCostShouldNotBeAvailable () {
		Assert.assertEquals("the meeting cost should be Double.NaN", Double.NaN, myMeeting.getMeetingCost());
	}
}
